Module tag
nodedb_
array
0.2.1
Module tag
Module Items
Enums
Functions
In nodedb_
array::
codec
nodedb_array
::
codec
Module
tag
Enums

Codec
Tag
One-byte codec tag at the front of a new-format (v4+) tile payload.
Functions

peek_
tag
Peek at the first byte of a tile payload and return the codec tag.