pub fn encode_tile_prefix_with_order(
schema: &ArraySchema,
tile_indices: &[u64],
bits: u32,
) -> ArrayResult<u64>Expand description
Encode whichever curve the schema declares for tile boundaries.
pub fn encode_tile_prefix_with_order(
schema: &ArraySchema,
tile_indices: &[u64],
bits: u32,
) -> ArrayResult<u64>Encode whichever curve the schema declares for tile boundaries.